==> flutter_quill-8.4.1.tar.gz: doc/todo.md <==
# Todo

This is a todo list page that added recently and will be updated soon.

## Table of contents
- [Todo](#todo)
  - [Table of contents](#table-of-contents)
  - [Flutter Quill](#flutter-quill)
    - [Features](#features)
    - [Improvemenets](#improvemenets)
    - [Bugs](#bugs)
  - [Flutter Quill Extensions](#flutter-quill-extensions)
    - [Features](#features-1)
    - [Improvemenets](#improvemenets-1)
    - [Bugs](#bugs-1)

## Flutter Quill

### Features

  1. Add a method to set TextInputAction, fore more [info](https://github.com/singerdmx/flutter-quill/issues/1328)
  2. Add support for Text magnification feature, for more [info](https://github.com/singerdmx/flutter-quill/issues/1504)
  3. Provide a way to expose quills undo redo stacks, for more [info](https://github.com/singerdmx/flutter-quill/issues/1381)
  4. Add callback to the `QuillToolbarColorButton` for custom color picking logic

### Improvemenets

 1. Improve the Raw Quill Editor, for more [info](https://github.com/singerdmx/flutter-quill/issues/1509)
 2. Provide more support to all the platforms

### Bugs

Empty for now.
Please go to the [issues](https://github.com/singerdmx/flutter-quill/issues)


## Flutter Quill Extensions

### Features
1. Add support for cropping an image, fore more [info](https://github.com/singerdmx/flutter-quill/issues/1494)
2. Add support for copying images to the Clipboard

### Improvemenets

Please check the todos, this list will be updated soon.

### Bugs

Please check the todos, this list will be updated soon.

==> flutter_quill-8.5.0.tar.gz: doc/todo.md <==
# Todo

This is a todo list page that added recently and will be updated soon.

## Table of contents
- [Todo](#todo)
  - [Table of contents](#table-of-contents)
  - [Flutter Quill](#flutter-quill)
    - [Features](#features)
    - [Improvemenets](#improvemenets)
    - [Bugs](#bugs)
  - [Flutter Quill Extensions](#flutter-quill-extensions)
    - [Features](#features-1)
    - [Improvemenets](#improvemenets-1)
    - [Bugs](#bugs-1)

## Flutter Quill

### Features

  1. Add a method to set TextInputAction, for more [info](https://github.com/singerdmx/flutter-quill/issues/1328)
  2. Add support for Text magnification feature, for more [info](https://github.com/singerdmx/flutter-quill/issues/1504)
  3. Provide a way to expose quills undo redo stacks, for more [info](https://github.com/singerdmx/flutter-quill/issues/1381)
  4. Add callback to the `QuillToolbarColorButton` for custom color picking logic

### Improvemenets

 1. Improve the Raw Quill Editor, for more [info](https://github.com/singerdmx/flutter-quill/issues/1509)
 2. Provide more support to all the platforms
 3. Extract the shared properties between `QuillRawEditorConfigurations` and `QuillEditorConfigurations`

### Bugs

Empty for now.
Please go to the [issues](https://github.com/singerdmx/flutter-quill/issues)


## Flutter Quill Extensions

### Features
1. Add support for cropping an image, fore more [info](https://github.com/singerdmx/flutter-quill/issues/1494)
2. Add support for copying images to the Clipboard

### Improvemenets

Please check the todos, this list will be updated soon.

### Bugs

Please check the todos, this list will be updated soon.
